summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--henrietta-cache.scm8
1 files changed, 4 insertions, 4 deletions
diff --git a/henrietta-cache.scm b/henrietta-cache.scm
index a08ae6a..ba99aa2 100644
--- a/henrietta-cache.scm
+++ b/henrietta-cache.scm
@@ -166,11 +166,11 @@ EOF
(download-and-extract
distribution-file-type uri cache-dir
(lambda (archive dir)
;; Instead of messing about with tar, zcat, bzcat, unzip etc,
;; we should use libarchive.
(case distribution-file-type
- ((targz) (sprintf "(cd ~A && zcat ~A | tar xf -)" (qs dir) (qs archive)))
- ((tarbz2) (sprintf "(cd ~A && bzcat ~A | tar xf -)" (qs dir) (qs archive)))
+ ((targz) (sprintf "(cd ~A && gunzip -c ~A | tar xf -)" (qs dir) (qs archive)))
+ ((tarbz2) (sprintf "(cd ~A && bunzip2 -c ~A | tar xf -)" (qs dir) (qs archive)))
((zip) (sprintf "unzip -d ~A -o -qq ~A" (qs dir) (qs archive)))
(else (error (sprintf "Unknown archive type `~S' (shouldn't happen!)"
distribution-file-type)))))))
@@ -166,11 +166,11 @@ EOF
distribution-file-type uri cache-dir
(lambda (archive dir)
- ;; Instead of messing about with tar, zcat, bzcat, unzip etc,
- ;; we should use libarchive.
+ ;; Instead of messing about with tar, gunzip, bunzip2, unzip
+ ;; etc, we should use libarchive.
(case distribution-file-type